@@ -1,6 +1,5 @@
 require "forwardable"
 require "gtk2"
-require "rd/rdfmt"
 
 require "rabbit/rabbit"
 require 'rabbit/frame'
@@ -119,6 +118,8 @@ module Rabbit
 
     def_delegators(:@renderer, :search_slide, :stop_slide_search, :searching?)
 
+    def_delegators(:@renderer, :draw_scaled_image, :draw_scaled_image=)
+
     def_delegators(:@source, :source=, :reset, :base)
 
     attr_reader :logger, :renderer, :last_modified
@@ -129,6 +130,7 @@ module Rabbit
 
     attr_accessor :saved_image_type, :rss_base_uri
     attr_accessor :output_html, :output_index_html
+    attr_accessor :source_filename
     attr_accessor :migemo_dictionary_search_path, :migemo_dictionary_name
     attr_accessor :font_resolution_ratio
 
@@ -144,7 +146,8 @@ module Rabbit
       @apply_theme_request_queue = []
       @auto_redraw_timer = nil
       @output_html = false
-      @rss_base_uri = true
+      @rss_base_uri = nil
+      @source_filename = nil
       @migemo_dictionary_search_path = []
       @migemo_dictionary_name = nil
       @limit_time = nil
@@ -211,6 +214,13 @@ module Rabbit
       end
     end
 
+    def slide_text(index=current_index)
+      return "" if slides.empty?
+      slide = slides[index]
+      return "" if slide.nil?
+      slide.text.strip
+    end
+
     def slides
       if @index_mode
         @index_slides
@@ -379,6 +389,7 @@ module Rabbit
                                         @output_index_html,
                                         @rss_base_uri)
         generator.pdf_filename = filename if /\.pdf/i =~ filename.to_s
+        generator.source_filename = @source_filename
         generator.save
       end
     end
