@@ -12,6 +12,7 @@ module Rabbit
     extend Forwardable
 
     def_delegators(:@loader, :keep_ratio, :keep_ratio=)
+    def_delegators(:@loader, :x_aspect_ratio, :y_aspect_ratio)
     def_delegators(:@loader, :pixbuf, :width, :height)
     def_delegators(:@loader, :original_width, :original_height)
     def_delegators(:@loader, :resize, :draw)
@@ -23,6 +24,7 @@ module Rabbit
         raise ImageFileDoesNotExistError.new(filename)
       end
       super(*args, &block)
+      Utils.stringify_hash_key!(props) if props
       @loader = Base.find_loader(filename).new(filename, props)
     end
   end
