@@ -5,6 +5,7 @@ require 'rabbit/parser/ext/inline'
 require 'rabbit/parser/ext/image'
 require 'rabbit/parser/ext/enscript'
 require 'rabbit/parser/ext/tex'
+require 'rabbit/parser/ext/aafigure'
 require 'rabbit/parser/ext/anthy'
 require 'rabbit/parser/ext/entity'
 
@@ -47,6 +48,9 @@ module Rabbit
           []
         end
 
+        def current_body
+          @slides.last.body
+        end
 
         #
         # Procedures
@@ -288,7 +292,9 @@ module Rabbit
         def block_plugin(src)
           return unless @parent
 
-          @parent << (evaluate_block_plugin(src) || text("{{#{src}}}"))
+          result = evaluate_block_plugin(src)
+          return if result == :no_element
+          @parent << (result || text("{{#{src}}}"))
         end
 
 
@@ -404,6 +410,7 @@ module Rabbit
         end
 
         class BlockPlugin
+          include GetText
           include Element
 
           def initialize(output)
@@ -411,7 +418,23 @@ module Rabbit
           end
 
           def image(source, props={})
-            Ext::Image.make_image(@output.canvas, source, props)
+            if props[:align].to_s == "right"
+              body = @output.current_body
+              if body["background-image"]
+                raise ParseError,
+                      _("multiple {{image, 'XXX.png', :align => :right}} " + \
+                        "isn't supported.")
+              end
+              body["background-image"] = source
+              props.each do |name, value|
+                name = name.to_s.gsub(/_/, '-')
+                value = value.to_s if name == "align"
+                body["background-image-#{name}"] = value
+              end
+              :no_element
+            else
+              Ext::Image.make_image(@output.canvas, source, props)
+            end
           end
           alias_method :img, :image
 
@@ -453,6 +476,14 @@ module Rabbit
             end
           end
           alias_method :mimetex, :mimeTeX
+
+          def aafigure(source, props={})
+            args = [@output.canvas, source]
+            Ext::Image.make_image_from_file(*args) do |src_file_path|
+              args = [src_file_path, props, @output.canvas]
+              [Ext::AAFigure.make_image_by_aafigure(*args), props]
+            end
+          end
         end
       end
     end
