@@ -8,7 +8,7 @@ require "rabbit/gettext"
 
 module Rabbit
 
-  VERSION = "0.6.4"
+  VERSION = "0.6.5"
 
   TMP_DIR_NAME = ".tmp"
 
@@ -84,6 +84,12 @@ module Rabbit
     end
   end
 
+  class AAFigureCanNotHandleError < ImageLoadWithExternalCommandError
+    def initialize(command, additional_info=nil)
+      super("aafigure", command, additional_info)
+    end
+  end
+
   class UnknownPropertyError < Error
     attr_reader :name
     def initialize(name)
