@@ -5,10 +5,6 @@ set_foreground(@default_foreground)
 set_background(@default_background)
 
 add_image_path("ruby-images")
-include_theme("image")
-include_theme("table")
-include_theme("newline-in-slides")
-include_theme("slide-number")
 include_theme("default-icon")
 include_theme("default-title-text")
 include_theme("default-text")
@@ -20,3 +16,13 @@ include_theme("default-preformatted")
 include_theme("default-block-quote")
 include_theme("default-foot-text")
 include_theme("default-description")
+include_theme("image")
+include_theme("table")
+include_theme("newline-in-slides")
+include_theme("slide-number")
+
+include_theme("per-slide-background-color")
+
+include_theme("background-image-toolkit")
+include_theme("per-slide-background-image")
+include_theme("body-background-image")
